@@ -34,7 +34,7 @@
         'IDLE': 0,
         'ACTIVE': 1,
         'WARNING': 2,
-        'ERROR': 3,
+        'ERROR': 3
     };
 
     /**
@@ -52,10 +52,11 @@
     };
 
     var applicationID = "2D4B1DA3";
-    var messageNamespace = 'urn:x-cast:com.connectsdk';
 
-    //var applicationID = "F4EB2E8E";
-    //var messageNamespace = 'urn:x-cast:com.google.cast.mediabrowser.v3';
+    // This is the beta version used for testing new changes
+    //applicationID = '27C4EB5B';
+
+    var messageNamespace = 'urn:x-cast:com.connectsdk';
 
     var CastPlayer = function () {
 
@@ -340,8 +341,6 @@
 
         var player = this;
 
-        var bitrateSetting = AppSettings.maxChromecastBitrate();
-
         var receiverName = null;
 
         if (castPlayer.session && castPlayer.session.receiver && castPlayer.session.receiver.friendlyName) {
@@ -353,11 +352,14 @@
             deviceId: ApiClient.deviceId(),
             accessToken: ApiClient.accessToken(),
             serverAddress: ApiClient.serverAddress(),
-            maxBitrate: bitrateSetting,
-            receiverName: receiverName,
-            supportsAc3: AppSettings.enableChromecastAc3()
+            receiverName: receiverName
         });
 
+        var bitrateSetting = AppSettings.maxChromecastBitrate();
+        if (bitrateSetting) {
+            message.maxBitrate = bitrateSetting;
+        }
+
         require(['chromecasthelpers'], function (chromecasthelpers) {
 
             chromecasthelpers.getServerAddress(ApiClient).then(function (serverAddress) {
@@ -674,14 +676,16 @@
 
         self.getTargets = function () {
 
-            var targets = [];
+            return new Promise(function (resolve, reject) {
 
-            if (castPlayer.hasReceivers) {
-                targets.push(self.getCurrentTargetInfo());
-            }
+                var targets = [];
 
-            return targets;
+                if (castPlayer.hasReceivers) {
+                    targets.push(self.getCurrentTargetInfo());
+                }
 
+                resolve(targets);
+            });
         };
 
         self.getCurrentTargetInfo = function () {
