@@ -95,9 +95,10 @@
 
             elem.innerHTML = '';
 
-            var deferred = DeferredBuilder.Deferred();
-            deferred.resolve();
-            return deferred.promise();
+            return new Promise(function (resolve, reject) {
+
+                resolve();
+            });
         }
     }
 
