@@ -66,11 +66,14 @@
         }
     }
 
-    function addUserToHeader(user) {
+    function updateUserInHeader(user) {
 
         var header = document.querySelector('.viewMenuBar');
 
-        if (user.name) {
+        var headerUserButton = header.querySelector('.headerUserButton');
+        var hasImage;
+
+        if (user && user.name) {
             if (user.imageUrl && AppInfo.enableUserImage) {
 
                 var userButtonHeight = 26;
@@ -81,16 +84,30 @@
                     url += "&height=" + (userButtonHeight * Math.max(devicePixelRatio || 1, 2));
                 }
 
-                var headerUserButton = header.querySelector('.headerUserButton');
                 if (headerUserButton) {
                     headerUserButton.icon = null;
                     headerUserButton.src = url;
                     headerUserButton.classList.add('headerUserButtonRound');
+                    hasImage = true;
                 }
             }
         }
 
-        updateLocalUser(user.localUser);
+        if (headerUserButton && !hasImage) {
+            headerUserButton.icon = 'person';
+            headerUserButton.src = null;
+            headerUserButton.classList.remove('headerUserButtonRound');
+
+            // Looks like a bug in paper-icon-button that this doesn't get removed
+            var headerUserButtonImg = headerUserButton.querySelector('img');
+            if (headerUserButtonImg) {
+                headerUserButtonImg.parentNode.removeChild(headerUserButtonImg);
+            }
+        }
+        if (user) {
+            updateLocalUser(user.localUser);
+        }
+
         requiresUserRefresh = false;
     }
 
@@ -140,11 +157,6 @@
         }
     }
 
-    function removeUserFromHeader() {
-        
-        updateLocalUser(null);
-    }
-
     function bindMenuEvents() {
 
         var mainDrawerButton = document.querySelector('.mainDrawerButton');
@@ -204,7 +216,7 @@
                     refreshLibraryInfoInDrawer(user, drawer);
                     refreshBottomUserInfoInDrawer(user, drawer);
 
-                    Events.trigger(document, 'libraryMenuCreated');
+                    document.dispatchEvent(new CustomEvent("libraryMenuCreated", {}));
                     updateLibraryMenu(user.localUser);
                 }
 
@@ -392,9 +404,7 @@
 
     function getUserViews(apiClient, userId) {
 
-        var deferred = $.Deferred();
-
-        apiClient.getUserViews({}, userId).then(function (result) {
+        return apiClient.getUserViews({}, userId).then(function (result) {
 
             var items = result.Items;
 
@@ -430,10 +440,8 @@
                 }
             }
 
-            deferred.resolveWith(null, [list]);
+            return list;
         });
-
-        return deferred.promise();
     }
 
     function updateLibraryMenu(user) {
@@ -779,7 +787,7 @@
         }
 
         if (requiresUserRefresh) {
-            ConnectionManager.user(window.ApiClient).then(addUserToHeader);
+            ConnectionManager.user(window.ApiClient).then(updateUserInHeader);
         }
     }
 
@@ -938,13 +946,13 @@
     Events.on(ConnectionManager, 'localusersignedin', function (e, user) {
         requiresLibraryMenuRefresh = true;
         requiresDrawerRefresh = true;
-        ConnectionManager.user(ConnectionManager.getApiClient(user.ServerId)).then(addUserToHeader);
+        ConnectionManager.user(ConnectionManager.getApiClient(user.ServerId)).then(updateUserInHeader);
     });
 
     Events.on(ConnectionManager, 'localusersignedout', function () {
         requiresLibraryMenuRefresh = true;
         requiresDrawerRefresh = true;
-        removeUserFromHeader();
+        updateUserInHeader();
     });
 
     Events.on(MediaController, 'playerchange', function () {
