@@ -605,8 +605,8 @@
 
             // This should be outside of the IF
             // But for now, if you change songs but keep the same artist, the backdrop will flicker because in-between songs it clears out the image
-            if (!browserInfo.safari) {
-                // Exclude from safari because it just doesn't perform well
+            if (!browserInfo.mobile) {
+                // Exclude from mobile because it just doesn't perform well
                 Backdrops.setBackdropUrl(page, backdropUrl);
             }
 
@@ -637,11 +637,11 @@
 
         if (currentPlayer) {
 
-            $(currentPlayer).off('playbackstart', onPlaybackStart)
-                .off('playbackstop', onPlaybackStopped)
-                .off('volumechange', onStateChanged)
-                .off('playstatechange', onStateChanged)
-                .off('positionchange', onStateChanged);
+            Events.off(currentPlayer, 'playbackstart', onPlaybackStart);
+            Events.off(currentPlayer, 'playbackstop', onPlaybackStopped);
+            Events.off(currentPlayer, 'volumechange', onStateChanged);
+            Events.off(currentPlayer, 'playstatechange', onStateChanged);
+            Events.off(currentPlayer, 'positionchange', onStateChanged);
 
             currentPlayer.endPlayerUpdates();
             currentPlayer = null;
@@ -663,11 +663,11 @@
             onStateChanged.call(player, { type: 'init' }, state);
         });
 
-        $(player).on('playbackstart', onPlaybackStart)
-            .on('playbackstop', onPlaybackStopped)
-            .on('volumechange', onStateChanged)
-            .on('playstatechange', onStateChanged)
-            .on('positionchange', onStateChanged);
+        Events.on(player, 'playbackstart', onPlaybackStart);
+        Events.on(player, 'playbackstop', onPlaybackStopped);
+        Events.on(player, 'volumechange', onStateChanged);
+        Events.on(player, 'playstatechange', onStateChanged);
+        Events.on(player, 'positionchange', onStateChanged);
 
         var playerInfo = MediaController.getPlayerInfo();
 
@@ -820,7 +820,7 @@
             }
         });
 
-        $(MediaController).on('playerchange', function () {
+        Events.on(MediaController, 'playerchange', function () {
             updateCastIcon(page);
         });
 
@@ -832,7 +832,7 @@
 
         currentImgUrl = null;
 
-        $(MediaController).on('playerchange', onPlayerChange);
+        Events.on(MediaController, 'playerchange', onPlayerChange);
 
         bindToPlayer(page, MediaController.getCurrentPlayer());
 
@@ -861,7 +861,7 @@
 
         releaseCurrentPlayer();
 
-        $(MediaController).off('playerchange', onPlayerChange);
+        Events.off(MediaController, 'playerchange', onPlayerChange);
 
         lastPlayerState = null;
         $(document.body).removeClass('hiddenViewMenuBar').removeClass('hiddenNowPlayingBar');
