@@ -12,6 +12,13 @@
 
 })();
 
+// Compatibility
+window.Logger = {
+    log: function (msg) {
+        console.log(msg);
+    }
+};
+
 var Dashboard = {
 
     filterHtml: function (html) {
@@ -303,6 +310,10 @@ var Dashboard = {
 
     showServerRestartWarning: function (systemInfo) {
 
+        if (AppInfo.isNativeApp) {
+            return;
+        }
+
         var html = '<span style="margin-right: 1em;">' + Globalize.translate('MessagePleaseRestart') + '</span>';
 
         if (systemInfo.CanSelfRestart) {
@@ -322,6 +333,10 @@ var Dashboard = {
 
     showDashboardRefreshNotification: function () {
 
+        if (AppInfo.isNativeApp) {
+            return;
+        }
+
         var html = '<span style="margin-right: 1em;">' + Globalize.translate('MessagePleaseRefreshPage') + '</span>';
 
         html += '<paper-button raised class="submit mini" onclick="this.disabled=\'disabled\';Dashboard.reloadPage();"><iron-icon icon="refresh"></iron-icon><span>' + Globalize.translate('ButtonRefresh') + '</span></paper-button>';
@@ -357,10 +372,6 @@ var Dashboard = {
 
     showFooterNotification: function (options) {
 
-        if (!AppInfo.enableFooterNotifications) {
-            return;
-        }
-
         var removeOnHide = !options.id;
 
         options.id = options.id || "notification" + new Date().getTime() + parseInt(Math.random());
@@ -888,7 +899,6 @@ var Dashboard = {
             html += '</div>';
 
             $('.content-primary', page).before(html);
-            Events.trigger(page, 'create');
         }
     },
 
@@ -1033,8 +1043,32 @@ var Dashboard = {
                 {
                     var args = cmd.Arguments;
 
-                    if (args.TimeoutMs) {
-                        Dashboard.showFooterNotification({ html: "<div><b>" + args.Header + "</b></div>" + args.Text, timeout: args.TimeoutMs });
+                    if (args.TimeoutMs && window.Notification && Notification.permission === "granted") {
+
+                        var notification = {
+                            title: args.Header,
+                            body: args.Text,
+                            vibrate: true,
+                            timeout: args.TimeoutMs
+                        };
+
+                        var notif = new Notification(notification.title, notification);
+
+                        if (notif.show) {
+                            notif.show();
+                        }
+
+                        if (notification.timeout) {
+                            setTimeout(function () {
+
+                                if (notif.close) {
+                                    notif.close();
+                                }
+                                else if (notif.cancel) {
+                                    notif.cancel();
+                                }
+                            }, notification.timeout);
+                        }
                     }
                     else {
                         Dashboard.alert({ title: args.Header, message: args.Text });
@@ -1054,7 +1088,7 @@ var Dashboard = {
             case 'SetRepeatMode':
                 break;
             default:
-                Logger.log('Unrecognized command: ' + cmd.Name);
+                console.log('Unrecognized command: ' + cmd.Name);
                 break;
         }
     },
@@ -1162,6 +1196,10 @@ var Dashboard = {
 
     showPackageInstallNotification: function (installation, status) {
 
+        if (AppInfo.isNativeApp) {
+            return;
+        }
+
         var html = '';
 
         if (status == 'completed') {
@@ -1223,7 +1261,7 @@ var Dashboard = {
 
         var newItems = data.ItemsAdded;
 
-        if (!newItems.length || AppInfo.isNativeApp || !window.Notification) {
+        if (!newItems.length || AppInfo.isNativeApp || !window.Notification || Notification.permission !== "granted") {
             return;
         }
 
@@ -1248,8 +1286,14 @@ var Dashboard = {
                 var notification = {
                     title: "New " + item.Type,
                     body: item.Name,
-                    timeout: 5000,
-                    vibrate: true
+                    timeout: 15000,
+                    vibrate: true,
+
+                    data: {
+                        options: {
+                            url: LibraryBrowser.getHref(item)
+                        }
+                    }
                 };
 
                 var imageTags = item.ImageTags || {};
@@ -1263,25 +1307,22 @@ var Dashboard = {
                     });
                 }
 
-                if (Notification.permission === "granted") {
+                var notif = new Notification(notification.title, notification);
 
-                    var notif = new Notification(notification.title, notification);
+                if (notif.show) {
+                    notif.show();
+                }
 
-                    if (notif.show) {
-                        notif.show();
-                    }
+                if (notification.timeout) {
+                    setTimeout(function () {
 
-                    if (notification.timeout) {
-                        setTimeout(function () {
-
-                            if (notif.close) {
-                                notif.close();
-                            }
-                            else if (notif.cancel) {
-                                notif.cancel();
-                            }
-                        }, notification.timeout);
-                    }
+                        if (notif.close) {
+                            notif.close();
+                        }
+                        else if (notif.cancel) {
+                            notif.cancel();
+                        }
+                    }, notification.timeout);
                 }
             }
         });
@@ -1514,6 +1555,7 @@ var AppInfo = {};
         AppInfo.enableNowPlayingBar = true;
         AppInfo.enableHomeTabs = true;
         AppInfo.enableNowPlayingPageBottomTabs = true;
+        AppInfo.enableAutoSave = browserInfo.mobile;
 
         AppInfo.enableAppStorePolicy = isCordova;
 
@@ -1566,7 +1608,6 @@ var AppInfo = {};
             }
         }
         else {
-            AppInfo.enableFooterNotifications = true;
             AppInfo.enableSupporterMembership = true;
 
             if (!isAndroid && !isIOS) {
@@ -1605,29 +1646,41 @@ var AppInfo = {};
         apiClient.getDefaultImageQuality = Dashboard.getDefaultImageQuality;
         apiClient.normalizeImageOptions = Dashboard.normalizeImageOptions;
 
-        $(apiClient).off("websocketmessage", Dashboard.onWebSocketMessageReceived).off('requestfail', Dashboard.onRequestFail);
+        Events.off(apiClient, 'websocketmessage', Dashboard.onWebSocketMessageReceived);
+        Events.on(apiClient, 'websocketmessage', Dashboard.onWebSocketMessageReceived);
 
-        $(apiClient).on("websocketmessage", Dashboard.onWebSocketMessageReceived).on('requestfail', Dashboard.onRequestFail);
+        Events.off(apiClient, 'requestfail', Dashboard.onRequestFail);
+        Events.on(apiClient, 'requestfail', Dashboard.onRequestFail);
+    }
+
+    function getSyncProfile() {
+
+        return getRequirePromise(['scripts/mediaplayer']).then(function () {
+            return MediaPlayer.getDeviceProfile(Math.max(screen.height, screen.width));
+        });
+    }
+
+    function onApiClientCreated(e, newApiClient) {
+        initializeApiClient(newApiClient);
     }
 
     //localStorage.clear();
-    function createConnectionManager(capabilities) {
+    function createConnectionManager(credentialProviderFactory, capabilities) {
 
         var credentialKey = Dashboard.isConnectMode() ? null : 'servercredentials4';
-        var credentialProvider = new MediaBrowser.CredentialProvider(credentialKey);
+        var credentialProvider = new credentialProviderFactory(credentialKey);
 
-        window.ConnectionManager = new MediaBrowser.ConnectionManager(Logger, credentialProvider, AppInfo.appName, AppInfo.appVersion, AppInfo.deviceName, AppInfo.deviceId, capabilities);
+        return getSyncProfile().then(function (deviceProfile) {
 
-        if (window.location.href.toLowerCase().indexOf('wizardstart.html') != -1) {
-            window.ConnectionManager.clearData();
-        }
+            capabilities.DeviceProfile = deviceProfile;
 
-        Events.on(ConnectionManager, 'apiclientcreated', function (e, newApiClient) {
+            window.ConnectionManager = new MediaBrowser.ConnectionManager(credentialProvider, AppInfo.appName, AppInfo.appVersion, AppInfo.deviceName, AppInfo.deviceId, capabilities, window.devicePixelRatio);
 
-            initializeApiClient(newApiClient);
-        });
+            if (window.location.href.toLowerCase().indexOf('wizardstart.html') != -1) {
+                window.ConnectionManager.clearData();
+            }
 
-        return new Promise(function (resolve, reject) {
+            Events.on(ConnectionManager, 'apiclientcreated', onApiClientCreated);
 
             if (Dashboard.isConnectMode()) {
 
@@ -1638,27 +1691,24 @@ var AppInfo = {};
                     if (server && server.UserId && server.AccessToken) {
                         Dashboard.showLoadingMsg();
 
-                        ConnectionManager.connectToServer(server).then(function (result) {
+                        return ConnectionManager.connectToServer(server).then(function (result) {
                             Dashboard.showLoadingMsg();
 
                             if (result.State == MediaBrowser.ConnectionState.SignedIn) {
                                 window.ApiClient = result.ApiClient;
                             }
-                            resolve();
                         });
-                        return;
                     }
                 }
-                resolve();
 
             } else {
-
-                var apiClient = new MediaBrowser.ApiClient(Logger, Dashboard.serverAddress(), AppInfo.appName, AppInfo.appVersion, AppInfo.deviceName, AppInfo.deviceId);
-                apiClient.enableAutomaticNetworking = false;
-                ConnectionManager.addApiClient(apiClient);
-                Dashboard.importCss(apiClient.getUrl('Branding/Css'));
-                window.ApiClient = apiClient;
-                resolve();
+                return getRequirePromise(['apiclient']).then(function (apiClientFactory) {
+                    var apiClient = new apiClientFactory(Dashboard.serverAddress(), AppInfo.appName, AppInfo.appVersion, AppInfo.deviceName, AppInfo.deviceId, window.devicePixelRatio);
+                    apiClient.enableAutomaticNetworking = false;
+                    ConnectionManager.addApiClient(apiClient);
+                    Dashboard.importCss(apiClient.getUrl('Branding/Css'));
+                    window.ApiClient = apiClient;
+                });
             }
         });
     }
@@ -1761,7 +1811,6 @@ var AppInfo = {};
         var urlArgs = "v=" + (window.dashboardVersion || new Date().getDate());
 
         var bowerPath = "bower_components";
-        var apiClientBowerPath = "bower_components/emby-apiclient";
 
         // Put the version into the bower path since we can't easily put a query string param on html imports
         // Emby server will handle this
@@ -1769,6 +1818,9 @@ var AppInfo = {};
             bowerPath += window.dashboardVersion;
         }
 
+        var apiClientBowerPath = bowerPath + "/emby-apiclient";
+        var embyWebComponentsBowerPath = bowerPath + '/emby-webcomponents';
+
         var paths = {
             velocity: bowerPath + "/velocity/velocity.min",
             tvguide: 'components/tvguide/tvguide',
@@ -1783,8 +1835,17 @@ var AppInfo = {};
             headroom: bowerPath + '/headroom.js/dist/headroom.min',
             masonry: bowerPath + '/masonry/dist/masonry.pkgd.min',
             humanedate: 'components/humanedate',
+            chromecasthelpers: 'components/chromecasthelpers',
             jQuery: bowerPath + '/jquery/dist/jquery.min',
-            fastclick: bowerPath + '/fastclick/lib/fastclick'
+            fastclick: bowerPath + '/fastclick/lib/fastclick',
+            events: apiClientBowerPath + '/events',
+            credentialprovider: apiClientBowerPath + '/credentials',
+            apiclient: apiClientBowerPath + '/apiclient',
+            connectionmanagerfactory: apiClientBowerPath + '/connectionmanager',
+            browserdeviceprofile: embyWebComponentsBowerPath + "/browserdeviceprofile",
+            browser: embyWebComponentsBowerPath + "/browser",
+            qualityoptions: embyWebComponentsBowerPath + "/qualityoptions",
+            connectservice: apiClientBowerPath + '/connectservice'
         };
 
         paths.hlsjs = bowerPath + "/hls.js/dist/hls.min";
@@ -1818,8 +1879,8 @@ var AppInfo = {};
         requirejs.config({
             map: {
                 '*': {
-                    'css': 'components/requirecss',
-                    'html': 'components/requirehtml'
+                    'css': bowerPath + '/emby-webcomponents/requirecss',
+                    'html': bowerPath + '/emby-webcomponents/requirehtml'
                 }
             },
             urlArgs: urlArgs,
@@ -1911,13 +1972,8 @@ var AppInfo = {};
             define("fileupload", [apiClientBowerPath + "/fileupload"]);
         }
 
-        define("connectservice", [apiClientBowerPath + "/connectservice"]);
         define("apiclient-store", [apiClientBowerPath + "/store"]);
-        define("apiclient-events", [apiClientBowerPath + "/events"]);
-        define("apiclient-logger", [apiClientBowerPath + "/logger"]);
-        define("apiclient-credentials", [apiClientBowerPath + "/credentials"]);
-        define("apiclient-deferred", [apiClientBowerPath + "/deferred"]);
-        define("apiclient", [apiClientBowerPath + "/apiclient"]);
+        define("apiclient-deferred", ["legacy/deferred"]);
         define("connectionmanager", [apiClientBowerPath + "/connectionmanager"]);
 
         define("contentuploader", [apiClientBowerPath + "/sync/contentuploader"]);
@@ -1988,6 +2044,7 @@ var AppInfo = {};
         define("buttonenabled", ["legacy/buttonenabled"]);
 
         var deps = [];
+        deps.push('events');
 
         if (!window.fetch) {
             deps.push('fetch');
@@ -1995,13 +2052,14 @@ var AppInfo = {};
 
         deps.push('scripts/mediacontroller');
         deps.push('scripts/globalize');
-        deps.push('apiclient-events');
 
         deps.push('jQuery');
 
         deps.push('paper-drawer-panel');
 
-        require(deps, function () {
+        require(deps, function (events) {
+
+            window.Events = events;
 
             for (var i in hostingAppInfo) {
                 AppInfo[i] = hostingAppInfo[i];
@@ -2037,19 +2095,19 @@ var AppInfo = {};
         }
 
         var deps = [];
-
-        if (AppInfo.isNativeApp && browserInfo.android) {
-            require(['cordova/android/logging']);
-        }
+        deps.push('connectionmanagerfactory');
+        deps.push('credentialprovider');
 
         deps.push('appstorage');
-        deps.push('scripts/mediaplayer');
         deps.push('scripts/appsettings');
-        deps.push('apiclient');
-        deps.push('connectionmanager');
-        deps.push('apiclient-credentials');
+        deps.push('scripts/extensions');
 
-        require(deps, function () {
+        require(deps, function (connectionManagerExports, credentialProviderFactory) {
+
+            window.MediaBrowser = window.MediaBrowser || {};
+            for (var i in connectionManagerExports) {
+                MediaBrowser[i] = connectionManagerExports[i];
+            }
 
             // TODO: This needs to be deprecated, but it's used heavily
             $.fn.checked = function (value) {
@@ -2084,12 +2142,9 @@ var AppInfo = {};
                 }
             }
 
-            var capabilities = Dashboard.capabilities();
-
-            capabilities.DeviceProfile = MediaPlayer.getDeviceProfile(Math.max(screen.height, screen.width));
-
             var promises = [];
             deps = [];
+            deps.push('scripts/mediaplayer');
             deps.push('thirdparty/jquery.unveil-custom.js');
             deps.push('emby-icons');
             deps.push('paper-icon-button');
@@ -2099,8 +2154,7 @@ var AppInfo = {};
             promises.push(getRequirePromise(deps));
 
             promises.push(Globalize.ensure());
-            promises.push(createConnectionManager(capabilities));
-
+            promises.push(createConnectionManager(credentialProviderFactory, Dashboard.capabilities()));
 
             Promise.all(promises).then(function () {
 
@@ -2196,7 +2250,6 @@ var AppInfo = {};
         deps.push('scripts/sync');
         deps.push('scripts/backdrops');
         deps.push('scripts/librarymenu');
-        deps.push('apiclient-deferred');
 
         deps.push('css!css/card.css');
 
@@ -2219,6 +2272,7 @@ var AppInfo = {};
             postInitDependencies.push('scripts/remotecontrol');
             postInitDependencies.push('css!css/notifications.css');
             postInitDependencies.push('css!css/chromecast.css');
+            postInitDependencies.push('apiclient-deferred');
 
             if (Dashboard.isRunningInCordova()) {
 
@@ -2255,6 +2309,8 @@ var AppInfo = {};
                 postInitDependencies.push('cordova/ios/tabbar');
             }
 
+            postInitDependencies.push('components/remotecontrolautoplay');
+
             require(postInitDependencies);
         });
     }
@@ -2355,111 +2411,38 @@ var AppInfo = {};
         return getWebHostingAppInfo();
     }
 
-    function setBrowserInfo(isMobile) {
-
-        var uaMatch = function (ua) {
-            ua = ua.toLowerCase();
-
-            var match = /(edge)[ \/]([\w.]+)/.exec(ua) ||
-                /(chrome)[ \/]([\w.]+)/.exec(ua) ||
-                /(safari)[ \/]([\w.]+)/.exec(ua) ||
-                /(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua) ||
-                /(msie) ([\w.]+)/.exec(ua) ||
-                ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) ||
-                [];
-
-            var platform_match = /(ipad)/.exec(ua) ||
-                /(iphone)/.exec(ua) ||
-                /(android)/.exec(ua) ||
-                [];
-
-            var browser = match[1] || "";
-
-            if (ua.indexOf("windows phone") != -1 || ua.indexOf("iemobile") != -1) {
-
-                // http://www.neowin.net/news/ie11-fakes-user-agent-to-fool-gmail-in-windows-phone-81-gdr1-update
-                browser = "msie";
-            }
-            else if (ua.indexOf("like gecko") != -1 && ua.indexOf('webkit') == -1 && ua.indexOf('opera') == -1 && ua.indexOf('chrome') == -1 && ua.indexOf('safari') == -1) {
-                browser = "msie";
-            }
-
-            return {
-                browser: browser,
-                version: match[2] || "0",
-                platform: platform_match[0] || ""
-            };
-        };
-
-        var userAgent = window.navigator.userAgent;
-        var matched = uaMatch(userAgent);
-        var browser = {};
-
-        if (matched.browser) {
-            browser[matched.browser] = true;
-            browser.version = matched.version;
-        }
-
-        if (matched.platform) {
-            browser[matched.platform] = true;
-        }
-
-        if (!browser.chrome && !browser.msie && !browser.edge && !browser.opera && userAgent.toLowerCase().indexOf("webkit") != -1) {
-            browser.safari = true;
-        }
-
-        if (isMobile.any) {
-            browser.mobile = true;
-        }
-
-        browser.animate = document.documentElement.animate != null;
-
-        window.browserInfo = browser;
-    }
-
     initRequire();
 
-    var initialDependencies = [];
+    function onWebComponentsReady() {
 
-    initialDependencies.push('isMobile');
-    initialDependencies.push('apiclient-logger');
-    initialDependencies.push('apiclient-store');
-    initialDependencies.push('scripts/extensions');
+        var initialDependencies = [];
 
-    var supportsNativeWebComponents = 'registerElement' in document && 'content' in document.createElement('template');
+        initialDependencies.push('browser');
+        initialDependencies.push('apiclient-store');
 
-    if (!supportsNativeWebComponents) {
-        initialDependencies.push('webcomponentsjs');
-    }
+        if (!window.Promise) {
+            initialDependencies.push('native-promise-only');
+        }
 
-    if (!window.Promise) {
-        initialDependencies.push('native-promise-only');
-    }
+        require(initialDependencies, function (browser) {
 
-    require(initialDependencies, function (isMobile) {
+            window.browserInfo = browser;
+            setAppInfo();
+            setDocumentClasses();
 
-        function onWebComponentsReady() {
-
-            var polymerDependencies = [];
-
-            require(polymerDependencies, function () {
-
-                getHostingAppInfo().then(function (hostingAppInfo) {
-                    init(hostingAppInfo);
-                });
+            getHostingAppInfo().then(function (hostingAppInfo) {
+                init(hostingAppInfo);
             });
-        }
+        });
+    }
 
-        setBrowserInfo(isMobile);
-        setAppInfo();
-        setDocumentClasses();
-
-        if (supportsNativeWebComponents) {
-            onWebComponentsReady();
-        } else {
-            document.addEventListener('WebComponentsReady', onWebComponentsReady);
-        }
-    });
+    if ('registerElement' in document && 'content' in document.createElement('template')) {
+        // Native web components support
+        onWebComponentsReady();
+    } else {
+        document.addEventListener('WebComponentsReady', onWebComponentsReady);
+        require(['webcomponentsjs']);
+    }
 
 })();
 
@@ -2566,7 +2549,7 @@ pageClassOn('pageshow', "page", function () {
 
         if (!isConnectMode && this.id !== "loginPage" && !page.classList.contains('forgotPasswordPage') && !page.classList.contains('forgotPasswordPinPage') && !page.classList.contains('wizardPage') && this.id !== 'publicSharedItemPage') {
 
-            Logger.log('Not logged into server. Redirecting to login.');
+            console.log('Not logged into server. Redirecting to login.');
             Dashboard.logout();
             return;
         }
@@ -2593,7 +2576,7 @@ window.addEventListener("beforeunload", function () {
         });
 
         if (!localActivePlayers.length) {
-            Logger.log('Sending close web socket command');
+            console.log('Sending close web socket command');
             apiClient.closeWebSocket();
         }
     }
