@@ -52,7 +52,6 @@
             var view = getPageData().view;
 
             var html = '';
-            var trigger = false;
             var pagingHtml = LibraryBrowser.getQueryPagingHtml({
                 startIndex: query.StartIndex,
                 limit: query.Limit,
@@ -113,7 +112,6 @@
                     context: 'tv',
                     sortBy: query.SortBy
                 });
-                trigger = true;
             }
             else if (view == "PosterCard") {
                 html = LibraryBrowser.getPosterViewHtml({
@@ -142,10 +140,6 @@
             elem.innerHTML = html + pagingHtml;
             ImageLoader.lazyChildren(elem);
 
-            if (trigger) {
-                Events.trigger(elem, 'create');
-            }
-
             $('.btnNextPage', page).on('click', function () {
                 query.StartIndex += query.Limit;
                 reloadItems(page, viewPanel);
